@@ -8,24 +8,30 @@ __all__ = [
     "SpinInFromNothing",
 ]
 
+import typing
+
+import numpy as np
 
 from ..animation.transform import Transform
 from ..constants import PI
 
+if typing.TYPE_CHECKING:
+    from ..mobject.geometry import Arrow
+    from ..mobject.mobject import Mobject
+
 
 class GrowFromPoint(Transform):
-    CONFIG = {
-        "point_color": None,
-    }
-
-    def __init__(self, mobject, point, **kwargs):
+    def __init__(
+        self, mobject: "Mobject", point: np.ndarray, point_color: str = None, **kwargs
+    ) -> None:
         self.point = point
+        self.point_color = point_color
         super().__init__(mobject, **kwargs)
 
-    def create_target(self):
+    def create_target(self) -> "Mobject":
         return self.mobject
 
-    def create_starting_mobject(self):
+    def create_starting_mobject(self) -> "Mobject":
         start = super().create_starting_mobject()
         start.scale(0)
         start.move_to(self.point)
@@ -35,24 +41,23 @@ class GrowFromPoint(Transform):
 
 
 class GrowFromCenter(GrowFromPoint):
-    def __init__(self, mobject, **kwargs):
+    def __init__(self, mobject: "Mobject", point_color: str = None, **kwargs) -> None:
         point = mobject.get_center()
-        super().__init__(mobject, point, **kwargs)
+        super().__init__(mobject, point, point_color=point_color, **kwargs)
 
 
 class GrowFromEdge(GrowFromPoint):
-    def __init__(self, mobject, edge, **kwargs):
+    def __init__(self, mobject: "Mobject", edge: np.ndarray, **kwargs) -> None:
         point = mobject.get_critical_point(edge)
         super().__init__(mobject, point, **kwargs)
 
 
 class GrowArrow(GrowFromPoint):
-    def __init__(self, arrow, **kwargs):
+    def __init__(self, arrow: "Arrow", **kwargs) -> None:
         point = arrow.get_start()
         super().__init__(arrow, point, **kwargs)
 
 
 class SpinInFromNothing(GrowFromCenter):
-    CONFIG = {
-        "path_arc": PI,
-    }
+    def __init__(self, mobject: "Mobject", path_arc: float = PI, **kwargs) -> None:
+        super().__init__(mobject, path_arc=path_arc, **kwargs)
