@@ -65,7 +65,6 @@ from ..mobject.mobject import Mobject
 from ..mobject.types.vectorized_mobject import VGroup
 from ..mobject.types.vectorized_mobject import VMobject
 from ..mobject.types.vectorized_mobject import DashedVMobject
-from ..utils.config_ops import digest_config
 from ..utils.iterables import adjacent_n_tuples
 from ..utils.iterables import adjacent_pairs
 from ..utils.simple_functions import fdiv
@@ -104,12 +103,17 @@ class TipableVMobject(VMobject):
 
     """
 
-    CONFIG = {
-        "tip_length": DEFAULT_ARROW_TIP_LENGTH,
-        # TODO
-        "normal_vector": OUT,
-        "tip_style": dict(),
-    }
+    def __init__(
+        self,
+        tip_length=DEFAULT_ARROW_TIP_LENGTH,
+        normal_vector=OUT,
+        tip_style={},
+        **kwargs
+    ):
+        self.tip_length = tip_length
+        self.normal_vector = normal_vector
+        self.tip_style = tip_style
+        VMobject.__init__(self, **kwargs)
 
     # Adding, Creating, Modifying tips
 
@@ -130,7 +134,7 @@ class TipableVMobject(VMobject):
 
     def create_tip(self, tip_shape=None, tip_length=None, at_start=False):
         """
-        Stylises the tip, positions it spacially, and returns
+        Stylises the tip, positions it spatially, and returns
         the newly instantiated tip to the caller.
         """
         tip = self.get_unpositioned_tip(tip_shape, tip_length)
@@ -255,18 +259,26 @@ class TipableVMobject(VMobject):
 class Arc(TipableVMobject):
     """A circular arc."""
 
-    CONFIG = {
-        "radius": 1.0,
-        "num_components": 9,
-        "anchors_span_full_range": True,
-        "arc_center": ORIGIN,
-    }
-
-    def __init__(self, start_angle=0, angle=TAU / 4, **kwargs):
+    def __init__(
+        self,
+        start_angle=0,
+        angle=TAU / 4,
+        radius=1.0,
+        num_components=9,
+        anchors_span_full_range=True,
+        arc_center=ORIGIN,
+        **kwargs
+    ):
+        if radius is None:  # apparently None is passed by ArcBetweenPoints
+            radius = 1.0
+        self.radius = radius
+        self.num_components = num_components
+        self.anchors_span_full_range = anchors_span_full_range
+        self.arc_center = arc_center
         self.start_angle = start_angle
         self.angle = angle
         self._failed_to_get_center = False
-        VMobject.__init__(self, **kwargs)
+        TipableVMobject.__init__(self, **kwargs)
 
     def generate_points(self):
         self.set_pre_positioned_points()
@@ -286,7 +298,7 @@ class Arc(TipableVMobject):
         # Appropriate tangent lines to the circle
         d_theta = self.angle / (self.num_components - 1.0)
         tangent_vectors = np.zeros(anchors.shape)
-        # Rotate all 90 degress, via (x, y) -> (-y, x)
+        # Rotate all 90 degrees, via (x, y) -> (-y, x)
         tangent_vectors[:, 1] = anchors[:, 0]
         tangent_vectors[:, 0] = -anchors[:, 1]
         # Use tangent vectors to deduce anchors
@@ -351,7 +363,7 @@ class ArcBetweenPoints(Arc):
             arc_height = radius - math.sqrt(radius ** 2 - halfdist ** 2)
             angle = math.acos((radius - arc_height) / radius) * sign
 
-        Arc.__init__(self, angle=angle, **kwargs)
+        Arc.__init__(self, radius=radius, angle=angle, **kwargs)
         if angle == 0:
             self.set_points_as_corners([LEFT, RIGHT])
         self.put_start_and_end_on(start, end)
@@ -367,29 +379,35 @@ class ArcBetweenPoints(Arc):
 class CurvedArrow(ArcBetweenPoints):
     def __init__(self, start_point, end_point, **kwargs):
         ArcBetweenPoints.__init__(self, start_point, end_point, **kwargs)
-        self.add_tip(tip_shape=kwargs.get("tip_shape", ArrowTriangleFilledTip))
+        self.add_tip(tip_shape=kwargs.pop("tip_shape", ArrowTriangleFilledTip))
 
 
 class CurvedDoubleArrow(CurvedArrow):
     def __init__(self, start_point, end_point, **kwargs):
         if "tip_shape_end" in kwargs:
             kwargs["tip_shape"] = kwargs.pop("tip_shape_end")
+        tip_shape_start = kwargs.pop("tip_shape_start", ArrowTriangleFilledTip)
         CurvedArrow.__init__(self, start_point, end_point, **kwargs)
-        self.add_tip(
-            at_start=True,
-            tip_shape=kwargs.get("tip_shape_start", ArrowTriangleFilledTip),
-        )
+        self.add_tip(at_start=True, tip_shape=tip_shape_start)
 
 
 class Circle(Arc):
-    CONFIG = {"color": RED, "close_new_points": True, "anchors_span_full_range": False}
-
-    def __init__(self, **kwargs):
-        Arc.__init__(self, 0, TAU, **kwargs)
+    def __init__(
+        self, color=RED, close_new_points=True, anchors_span_full_range=False, **kwargs
+    ):
+        Arc.__init__(
+            self,
+            start_angle=0,
+            angle=TAU,
+            color=color,
+            close_new_points=close_new_points,
+            anchors_span_full_range=anchors_span_full_range,
+            **kwargs
+        )
 
     def surround(self, mobject, dim_to_match=0, stretch=False, buffer_factor=1.2):
         # Ignores dim_to_match and stretch; result will always be a circle
-        # TODO: Perhaps create an ellipse class to handle singele-dimension stretching
+        # TODO: Perhaps create an ellipse class to handle single-dimension stretching
 
         # Something goes wrong here when surrounding lines?
         # TODO: Figure out and fix
@@ -404,15 +422,24 @@ class Circle(Arc):
 
 
 class Dot(Circle):
-    CONFIG = {
-        "radius": DEFAULT_DOT_RADIUS,
-        "stroke_width": 0,
-        "fill_opacity": 1.0,
-        "color": WHITE,
-    }
-
-    def __init__(self, point=ORIGIN, **kwargs):
-        Circle.__init__(self, arc_center=point, **kwargs)
+    def __init__(
+        self,
+        point=ORIGIN,
+        radius=DEFAULT_DOT_RADIUS,
+        stroke_width=0,
+        fill_opacity=1.0,
+        color=WHITE,
+        **kwargs
+    ):
+        Circle.__init__(
+            self,
+            arc_center=point,
+            radius=radius,
+            stroke_width=stroke_width,
+            fill_opacity=fill_opacity,
+            color=color,
+            **kwargs
+        )
 
 
 class SmallDot(Dot):
@@ -420,7 +447,8 @@ class SmallDot(Dot):
     A dot with small radius
     """
 
-    CONFIG = {"radius": DEFAULT_SMALL_DOT_RADIUS}
+    def __init__(self, radius=DEFAULT_SMALL_DOT_RADIUS, **kwargs):
+        Dot.__init__(self, radius=radius, **kwargs)
 
 
 class AnnotationDot(Dot):
@@ -428,12 +456,22 @@ class AnnotationDot(Dot):
     A dot with bigger radius and bold stroke to annotate scenes.
     """
 
-    CONFIG = {
-        "radius": DEFAULT_DOT_RADIUS * 1.3,
-        "stroke_width": 5,
-        "stroke_color": WHITE,
-        "fill_color": BLUE,
-    }
+    def __init__(
+        self,
+        radius=DEFAULT_DOT_RADIUS * 1.3,
+        stroke_width=5,
+        stroke_color=WHITE,
+        fill_color=BLUE,
+        **kwargs
+    ):
+        Dot.__init__(
+            self,
+            radius=radius,
+            stroke_width=stroke_width,
+            stroke_color=stroke_color,
+            fill_color=fill_color,
+            **kwargs
+        )
 
 
 class LabeledDot(Dot):
@@ -490,24 +528,37 @@ class LabeledDot(Dot):
 
 
 class Ellipse(Circle):
-    CONFIG = {"width": 2, "height": 1}
-
-    def __init__(self, **kwargs):
+    def __init__(self, width=2, height=1, **kwargs):
         Circle.__init__(self, **kwargs)
+        self.width = width
+        self.height = height
         self.set_width(self.width, stretch=True)
         self.set_height(self.height, stretch=True)
 
 
 class AnnularSector(Arc):
-    CONFIG = {
-        "inner_radius": 1,
-        "outer_radius": 2,
-        "angle": TAU / 4,
-        "start_angle": 0,
-        "fill_opacity": 1,
-        "stroke_width": 0,
-        "color": WHITE,
-    }
+    def __init__(
+        self,
+        inner_radius=1,
+        outer_radius=2,
+        angle=TAU / 4,
+        start_angle=0,
+        fill_opacity=1,
+        stroke_width=0,
+        color=WHITE,
+        **kwargs
+    ):
+        self.inner_radius = inner_radius
+        self.outer_radius = outer_radius
+        Arc.__init__(
+            self,
+            start_angle=start_angle,
+            angle=angle,
+            fill_opacity=fill_opacity,
+            stroke_width=stroke_width,
+            color=color,
+            **kwargs
+        )
 
     def generate_points(self):
         inner_arc, outer_arc = [
@@ -527,18 +578,33 @@ class AnnularSector(Arc):
 
 
 class Sector(AnnularSector):
-    CONFIG = {"outer_radius": 1, "inner_radius": 0}
+    def __init__(self, outer_radius=1, inner_radius=0, **kwargs):
+        AnnularSector.__init__(
+            self, inner_radius=inner_radius, outer_radius=outer_radius, **kwargs
+        )
 
 
 class Annulus(Circle):
-    CONFIG = {
-        "inner_radius": 1,
-        "outer_radius": 2,
-        "fill_opacity": 1,
-        "stroke_width": 0,
-        "color": WHITE,
-        "mark_paths_closed": False,
-    }
+    def __init__(
+        self,
+        inner_radius=1,
+        outer_radius=2,
+        fill_opacity=1,
+        stroke_width=0,
+        color=WHITE,
+        mark_paths_closed=False,
+        **kwargs
+    ):
+        self.mark_paths_closed = mark_paths_closed  # is this even used?
+        self.inner_radius = inner_radius
+        self.outer_radius = outer_radius
+        Circle.__init__(
+            self,
+            fill_opacity=fill_opacity,
+            stroke_width=stroke_width,
+            color=color,
+            **kwargs
+        )
 
     def generate_points(self):
         self.radius = self.outer_radius
@@ -551,12 +617,11 @@ class Annulus(Circle):
 
 
 class Line(TipableVMobject):
-    CONFIG = {"buff": 0, "path_arc": None}  # angle of arc specified here
-
-    def __init__(self, start=LEFT, end=RIGHT, **kwargs):
-        digest_config(self, kwargs)
+    def __init__(self, start=LEFT, end=RIGHT, buff=0, path_arc=None, **kwargs):
+        self.buff = buff
+        self.path_arc = path_arc
         self.set_start_and_end_attrs(start, end)
-        VMobject.__init__(self, **kwargs)
+        TipableVMobject.__init__(self, **kwargs)
 
     def generate_points(self):
         if self.path_arc:
@@ -645,18 +710,36 @@ class Line(TipableVMobject):
 
 
 class DashedLine(Line):
-    CONFIG = {
-        "dash_length": DEFAULT_DASH_LENGTH,
-        "dash_spacing": None,
-        "positive_space_ratio": 0.5,
-    }
+    """A dashed Line.
 
-    def __init__(self, *args, **kwargs):
+    Examples
+    --------
+    .. manim:: DashedLineExample
+        :save_last_frame:
+
+        class DashedLineExample(Scene):
+            def construct(self):
+                dashed_line = DashedLine(config.frame_width/2*LEFT, 4*RIGHT)
+                self.add(dashed_line)
+
+    """
+
+    def __init__(
+        self,
+        *args,
+        dash_length=DEFAULT_DASH_LENGTH,
+        dash_spacing=None,
+        positive_space_ratio=0.5,
+        **kwargs
+    ):
+        self.dash_length = dash_length
+        self.dash_spacing = (dash_spacing,)
+        self.positive_space_ratio = positive_space_ratio
         Line.__init__(self, *args, **kwargs)
-        ps_ratio = self.positive_space_ratio
-        num_dashes = self.calculate_num_dashes(ps_ratio)
         dashes = DashedVMobject(
-            self, num_dashes=num_dashes, positive_space_ratio=ps_ratio
+            self,
+            num_dashes=self.calculate_num_dashes(positive_space_ratio),
+            positive_space_ratio=positive_space_ratio,
         )
         self.clear_points()
         self.add(*dashes)
@@ -691,10 +774,9 @@ class DashedLine(Line):
 
 
 class TangentLine(Line):
-    CONFIG = {"length": 1, "d_alpha": 1e-6}
-
-    def __init__(self, vmob, alpha, **kwargs):
-        digest_config(self, kwargs)
+    def __init__(self, vmob, alpha, length=1, d_alpha=1e-6, **kwargs):
+        self.length = length
+        self.d_alpha = d_alpha
         da = self.d_alpha
         a1 = np.clip(alpha - da, 0, 1)
         a2 = np.clip(alpha + da, 0, 1)
@@ -705,9 +787,9 @@ class TangentLine(Line):
 
 
 class Elbow(VMobject):
-    CONFIG = {"width": 0.2, "angle": 0}
-
-    def __init__(self, **kwargs):
+    def __init__(self, width=0.2, angle=0, **kwargs):
+        self.width = width
+        self.angle = angle
         VMobject.__init__(self, **kwargs)
         self.set_points_as_corners([UP, UP + RIGHT, RIGHT])
         self.set_width(self.width, about_point=ORIGIN)
@@ -715,20 +797,31 @@ class Elbow(VMobject):
 
 
 class Arrow(Line):
-    CONFIG = {
-        "stroke_width": 6,
-        "buff": MED_SMALL_BUFF,
-        "max_tip_length_to_length_ratio": 0.25,
-        "max_stroke_width_to_length_ratio": 5,
-        "preserve_tip_size_when_scaling": True,
-    }
-
-    def __init__(self, *args, **kwargs):
-        Line.__init__(self, *args, **kwargs)
+    def __init__(
+        self,
+        *args,
+        stroke_width=6,
+        buff=MED_SMALL_BUFF,
+        max_tip_length_to_length_ratio=0.25,
+        max_stroke_width_to_length_ratio=5,
+        preserve_tip_size_when_scaling=True,
+        **kwargs
+    ):
+        self.max_tip_length_to_length_ratio = (
+            max_tip_length_to_length_ratio  # is this used anywhere
+        )
+        self.max_stroke_width_to_length_ratio = (
+            max_stroke_width_to_length_ratio  # is this used anywhere
+        )
+        self.preserve_tip_size_when_scaling = (
+            preserve_tip_size_when_scaling  # is this used anywhere
+        )
+        tip_shape = kwargs.pop("tip_shape", ArrowTriangleFilledTip)
+        Line.__init__(self, *args, buff=buff, stroke_width=stroke_width, **kwargs)
         # TODO, should this be affected when
         # Arrow.set_stroke is called?
         self.initial_stroke_width = self.stroke_width
-        self.add_tip(tip_shape=kwargs.get("tip_shape", ArrowTriangleFilledTip))
+        self.add_tip(tip_shape=tip_shape)
         self.set_stroke_width_from_length()
 
     def scale(self, factor, scale_tips=False, **kwargs):
@@ -746,7 +839,7 @@ class Arrow(Line):
             >>> scaled_arrow = arrow.scale(2)
             >>> scaled_arrow.get_start_and_end()
             (array([-2., -2.,  0.]), array([2., 2., 0.]))
-            >>> arrow.tip.tip_length == scaled_arrow.tip.tip_length
+            >>> arrow.tip.length == scaled_arrow.tip.length
             True
 
         Manually scaling the object using the default method
@@ -754,7 +847,7 @@ class Arrow(Line):
 
             >>> new_arrow = Arrow(np.array([-1, -1, 0]), np.array([1, 1, 0]), buff=0)
             >>> another_scaled_arrow = VMobject.scale(new_arrow, 2)
-            >>> another_scaled_arrow.tip.tip_length == arrow.tip.tip_length
+            >>> another_scaled_arrow.tip.length == arrow.tip.length
             False
 
         """
@@ -801,23 +894,20 @@ class Arrow(Line):
 
 
 class Vector(Arrow):
-    CONFIG = {"buff": 0}
-
-    def __init__(self, direction=RIGHT, **kwargs):
+    def __init__(self, direction=RIGHT, buff=0, **kwargs):
+        self.buff = buff
         if len(direction) == 2:
             direction = np.append(np.array(direction), 0)
-        Arrow.__init__(self, ORIGIN, direction, **kwargs)
+        Arrow.__init__(self, ORIGIN, direction, buff=buff, **kwargs)
 
 
 class DoubleArrow(Arrow):
     def __init__(self, *args, **kwargs):
         if "tip_shape_end" in kwargs:
             kwargs["tip_shape"] = kwargs.pop("tip_shape_end")
+        tip_shape_start = kwargs.pop("tip_shape_start", ArrowTriangleFilledTip)
         Arrow.__init__(self, *args, **kwargs)
-        self.add_tip(
-            at_start=True,
-            tip_shape=kwargs.get("tip_shape_start", ArrowTriangleFilledTip),
-        )
+        self.add_tip(at_start=True, tip_shape=tip_shape_start)
 
 
 class CubicBezier(VMobject):
@@ -827,10 +917,8 @@ class CubicBezier(VMobject):
 
 
 class Polygon(VMobject):
-    CONFIG = {"color": BLUE}
-
-    def __init__(self, *vertices, **kwargs):
-        VMobject.__init__(self, **kwargs)
+    def __init__(self, *vertices, color=BLUE, **kwargs):
+        VMobject.__init__(self, color=color, **kwargs)
         self.set_points_as_corners([*vertices, vertices[0]])
 
     def get_vertices(self):
@@ -872,10 +960,8 @@ class Polygon(VMobject):
 
 
 class RegularPolygon(Polygon):
-    CONFIG = {"start_angle": None}
-
-    def __init__(self, n=6, **kwargs):
-        digest_config(self, kwargs, locals())
+    def __init__(self, n=6, start_angle=None, **kwargs):
+        self.start_angle = start_angle
         if self.start_angle is None:
             if n % 2 == 0:
                 self.start_angle = 0
@@ -1130,34 +1216,33 @@ class Triangle(RegularPolygon):
 
 
 class Rectangle(Polygon):
-    CONFIG = {
-        "color": WHITE,
-        "height": 2.0,
-        "width": 4.0,
-        "mark_paths_closed": True,
-        "close_new_points": True,
-    }
-
-    def __init__(self, **kwargs):
-        Polygon.__init__(self, UL, UR, DR, DL, **kwargs)
+    def __init__(
+        self,
+        color=WHITE,
+        height=2.0,
+        width=4.0,
+        mark_paths_closed=True,
+        close_new_points=True,
+        **kwargs
+    ):
+        self.height = height
+        self.width = width
+        self.mark_paths_closed = mark_paths_closed
+        self.close_new_points = close_new_points
+        Polygon.__init__(self, UL, UR, DR, DL, color=color, **kwargs)
         self.set_width(self.width, stretch=True)
         self.set_height(self.height, stretch=True)
 
 
 class Square(Rectangle):
-    CONFIG = {"side_length": 2.0}
-
-    def __init__(self, **kwargs):
-        digest_config(self, kwargs)
-        Rectangle.__init__(
-            self, height=self.side_length, width=self.side_length, **kwargs
-        )
+    def __init__(self, side_length=2.0, **kwargs):
+        self.side_length = side_length
+        Rectangle.__init__(self, height=side_length, width=side_length, **kwargs)
 
 
 class RoundedRectangle(Rectangle):
-    CONFIG = {"corner_radius": 0.5}
-
-    def __init__(self, **kwargs):
+    def __init__(self, corner_radius=0.5, **kwargs):
+        self.corner_radius = corner_radius
         Rectangle.__init__(self, **kwargs)
         self.round_corners(self.corner_radius)
 
@@ -1191,8 +1276,9 @@ class ArrowTip(VMobject):
         >>> class MyCustomArrowTip(ArrowTip, RegularPolygon):
         ...     def __init__(self, **kwargs):
         ...         RegularPolygon.__init__(self, n=5, **kwargs)
-        ...         self.set_width(self.length)
-        ...         self.set_height(self.length, stretch=True)
+        ...         length = 0.35
+        ...         self.set_width(length)
+        ...         self.set_height(length, stretch=True)
         >>> arr = Arrow(np.array([-2, -2, 0]), np.array([2, 2, 0]),
         ...             tip_shape=MyCustomArrowTip)
         >>> isinstance(arr.tip, RegularPolygon)
@@ -1231,12 +1317,6 @@ class ArrowTip(VMobject):
                 self.add(a00, a11, a12, a21, a22, a31, a32, b11, b12, b21)
 
     """
-    CONFIG = {
-        "fill_opacity": 0,
-        "stroke_width": 3,
-        "length": DEFAULT_ARROW_TIP_LENGTH,
-        "start_angle": PI,
-    }
 
     def __init__(self, *args, **kwargs):
         raise NotImplementedError("Has to be implemented in inheriting subclasses.")
@@ -1304,7 +1384,7 @@ class ArrowTip(VMobject):
         return angle_of_vector(self.vector)
 
     @property
-    def tip_length(self):
+    def length(self):
         r"""The length of the arrow tip.
 
         Examples
@@ -1312,85 +1392,105 @@ class ArrowTip(VMobject):
         ::
 
             >>> arrow = Arrow(np.array([0, 0, 0]), np.array([1, 2, 0]))
-            >>> round(arrow.tip.tip_length, 3)
+            >>> round(arrow.tip.length, 3)
             0.35
 
         """
         return get_norm(self.vector)
 
 
-class ArrowFilledTip(ArrowTip):
-    r"""Base class for arrow tips with filled tip.
-
-    Note
-    ----
-    In comparison to :class:`ArrowTip`, this class only provides
-    different default settings for styling arrow tips. These settings
-    (in particular `fill_opacity` and `stroke_width`) can also be
-    overridden manually.
-
-    See Also
-    --------
-    :class:`ArrowTip`
-    :class:`ArrowTriangleFilledTip`
-    :class:`ArrowCircleFilledTip`
-    :class:`ArrowSquareFilledTip`
-
-    """
-    CONFIG = {
-        "fill_opacity": 1,
-        "stroke_width": 0,
-        "length": DEFAULT_ARROW_TIP_LENGTH,
-        "start_angle": PI,
-    }
-
-
 class ArrowTriangleTip(ArrowTip, Triangle):
     r"""Triangular arrow tip."""
 
-    def __init__(self, **kwargs):
-        digest_config(self, kwargs)
-        Triangle.__init__(self, **kwargs)
-        self.set_width(self.length)
-        self.set_height(self.length, stretch=True)
+    def __init__(
+        self,
+        fill_opacity=0,
+        stroke_width=3,
+        length=DEFAULT_ARROW_TIP_LENGTH,
+        start_angle=PI,
+        **kwargs
+    ):
+        Triangle.__init__(
+            self,
+            fill_opacity=fill_opacity,
+            stroke_width=stroke_width,
+            start_angle=start_angle,
+            **kwargs
+        )
+        self.set_width(length)
+        self.set_height(length, stretch=True)
 
 
-class ArrowTriangleFilledTip(ArrowFilledTip, ArrowTriangleTip):
+class ArrowTriangleFilledTip(ArrowTriangleTip):
     r"""Triangular arrow tip with filled tip.
 
     This is the default arrow tip shape.
     """
-    pass
+
+    def __init__(self, fill_opacity=1, stroke_width=0, **kwargs):
+        ArrowTriangleTip.__init__(
+            self, fill_opacity=fill_opacity, stroke_width=stroke_width, **kwargs
+        )
 
 
 class ArrowCircleTip(ArrowTip, Circle):
     r"""Circular arrow tip."""
 
-    def __init__(self, **kwargs):
-        digest_config(self, kwargs)
-        Circle.__init__(self, **kwargs)
-        self.set_width(self.length)
-        self.set_height(self.length, stretch=True)
+    def __init__(
+        self,
+        fill_opacity=0,
+        stroke_width=3,
+        length=DEFAULT_ARROW_TIP_LENGTH,
+        start_angle=PI,
+        **kwargs
+    ):
+        self.start_angle = start_angle
+        Circle.__init__(
+            self, fill_opacity=fill_opacity, stroke_width=stroke_width, **kwargs
+        )
+        self.set_width(length)
+        self.set_height(length, stretch=True)
 
 
-class ArrowCircleFilledTip(ArrowFilledTip, ArrowCircleTip):
+class ArrowCircleFilledTip(ArrowCircleTip):
     r"""Circular arrow tip with filled tip."""
-    pass
+
+    def __init__(self, fill_opacity=1, stroke_width=0, **kwargs):
+        ArrowCircleTip.__init__(
+            self, fill_opacity=fill_opacity, stroke_width=stroke_width, **kwargs
+        )
 
 
 class ArrowSquareTip(ArrowTip, Square):
     r"""Square arrow tip."""
 
-    def __init__(self, **kwargs):
-        digest_config(self, kwargs)
-        Square.__init__(self, side_length=self.length, **kwargs)
-        self.set_width(self.length)
-        self.set_height(self.length, stretch=True)
+    def __init__(
+        self,
+        fill_opacity=0,
+        stroke_width=3,
+        length=DEFAULT_ARROW_TIP_LENGTH,
+        start_angle=PI,
+        **kwargs
+    ):
+        self.start_angle = start_angle
+        Square.__init__(
+            self,
+            fill_opacity=fill_opacity,
+            stroke_width=stroke_width,
+            side_length=length,
+            **kwargs
+        )
+        self.set_width(length)
+        self.set_height(length, stretch=True)
 
 
-class ArrowSquareFilledTip(ArrowFilledTip, ArrowSquareTip):
+class ArrowSquareFilledTip(ArrowSquareTip):
     r"""Square arrow tip with filled tip."""
-    pass
+
+    def __init__(self, fill_opacity=1, stroke_width=0, **kwargs):
+        ArrowSquareTip.__init__(
+            self, fill_opacity=fill_opacity, stroke_width=stroke_width, **kwargs
+        )
 
 
 class Cutout(VMobject):
