@@ -42,26 +42,65 @@ class Mobject(Container):
 
     """
 
-    CONFIG = {
-        "color": WHITE,
-        "name": None,
-        "dim": 3,
-        "target": None,
-        "z_index": 0,
-    }
-
-    def __init__(self, **kwargs):
-        Container.__init__(self, **kwargs)
+    def __init__(self, color=WHITE, name=None, dim=3, target=None, z_index=0, **kwargs):
+        self.color = Color(color)
+        self.name = self.__class__.__name__ if name is None else name
+        self.dim = dim
+        self.target = target
+        self.z_index = z_index
         self.point_hash = None
         self.submobjects = []
-        self.color = Color(self.color)
-        if self.name is None:
-            self.name = self.__class__.__name__
         self.updaters = []
         self.updating_suspended = False
         self.reset_points()
         self.generate_points()
         self.init_colors()
+        Container.__init__(self, **kwargs)
+
+    @property
+    def animate(self):
+        """Used to animate the application of a method.
+
+        .. warning::
+
+            Passing multiple animations for the same :class:`~.Mobject` in one
+            call to :meth:`~.Scene.play` is discouraged and will most likely
+            not work properly. Instead of writing an animation like
+
+            ::
+
+                self.play(my_mobject.animate.shift(RIGHT), my_mobject.animate.rotate(PI))
+
+            make use of method chaining for ``animate``, meaning::
+
+                self.play(my_mobject.animate.shift(RIGHT).rotate(PI))
+
+        Examples
+        --------
+
+        .. manim:: AnimateExample
+
+            class AnimateExample(Scene):
+                def construct(self):
+                    s = Square()
+                    self.play(ShowCreation(s))
+                    self.play(s.animate.shift(RIGHT))
+                    self.play(s.animate.scale(2))
+                    self.play(s.animate.rotate(PI / 2))
+                    self.play(Uncreate(s))
+
+
+        .. manim:: AnimateChainExample
+
+            class AnimateChainExample(Scene):
+                def construct(self):
+                    s = Square()
+                    self.play(ShowCreation(s))
+                    self.play(s.animate.shift(RIGHT).scale(2).rotate(PI / 2))
+                    self.play(Uncreate(s))
+
+        """
+        return _AnimationBuilder(self)
 
     def __repr__(self):
         return str(self.name)
@@ -82,6 +121,8 @@ class Mobject(Container):
 
         The mobjects are added to self.submobjects.
 
+        Subclasses of mobject may implement + and += dunder methods.
+
         Parameters
         ----------
         mobjects : :class:`Mobject`
@@ -141,7 +182,22 @@ class Mobject(Container):
         self.submobjects = list_update(self.submobjects, mobjects)
         return self
 
+    def __add__(self, mobject):
+        raise NotImplementedError
+
+    def __iadd__(self, mobject):
+        raise NotImplementedError
+
     def add_to_back(self, *mobjects):
+        """Adds (or moves) all passed mobjects to the back of the scene.
+
+        .. note::
+
+            Technically, this is done by adding (or moving) the mobjects to
+            the head of ``self.submobjects``. The head of this list is rendered
+            first, which places the corresponding mobjects behind the
+            subsequent list members.
+        """
         self.remove(*mobjects)
         self.submobjects = list(mobjects) + self.submobjects
         return self
@@ -151,6 +207,8 @@ class Mobject(Container):
 
         The mobjects are removed from self.submobjects, if they exist.
 
+        Subclasses of mobject may implement - and -= dunder methods.
+
         Parameters
         ----------
         mobjects : :class:`Mobject`
@@ -171,20 +229,15 @@ class Mobject(Container):
                 self.submobjects.remove(mobject)
         return self
 
+    def __sub__(self, other):
+        raise NotImplementedError
+
+    def __isub__(self, other):
+        raise NotImplementedError
+
     def get_array_attrs(self):
         return ["points"]
 
-    def digest_mobject_attrs(self):
-        """
-        Ensures all attributes which are mobjects are included
-        in the submobjects list.
-        """
-        mobject_attrs = [
-            x for x in list(self.__dict__.values()) if isinstance(x, Mobject)
-        ]
-        self.submobjects = list_update(self.submobjects, mobject_attrs)
-        return self
-
     def apply_over_attr_arrays(self, func):
         for attr in self.get_array_attrs():
             setattr(self, attr, func(getattr(self, attr)))
@@ -212,9 +265,9 @@ class Mobject(Container):
         return copy.deepcopy(self)
 
     def generate_target(self, use_deepcopy=False):
-        self.target = None  # Prevent exponential explosion
+        self.target = None  # Prevent unbounded linear recursion
         if use_deepcopy:
-            self.target = self.deepcopy()
+            self.target = copy.deepcopy(self)
         else:
             self.target = self.copy()
         return self.target
@@ -589,7 +642,7 @@ class Mobject(Container):
         return self.rescale_to_fit(height, 1, stretch=True, **kwargs)
 
     def stretch_to_fit_depth(self, depth, **kwargs):
-        return self.rescale_to_fit(depth, 1, stretch=True, **kwargs)
+        return self.rescale_to_fit(depth, 2, stretch=True, **kwargs)
 
     def set_width(self, width, stretch=False, **kwargs):
         return self.rescale_to_fit(width, 0, stretch=stretch, **kwargs)
@@ -1032,9 +1085,32 @@ class Mobject(Container):
     def family_members_with_points(self):
         return [m for m in self.get_family() if m.get_num_points() > 0]
 
-    def arrange(self, direction=RIGHT, center=True, **kwargs):
+    def arrange(
+        self,
+        direction=RIGHT,
+        buff=DEFAULT_MOBJECT_TO_MOBJECT_BUFFER,
+        center=True,
+        **kwargs,
+    ):
+        """sort mobjects next to each other on screen.
+
+        Examples
+        --------
+
+        .. manim:: Example
+            :save_last_frame:
+
+            class Example(Scene):
+                def construct(self):
+                    s1 = Square()
+                    s2 = Square()
+                    s3 = Square()
+                    s4 = Square()
+                    x = VGroup(s1, s2, s3, s4).set_x(0).arrange(buff=1.0)
+                    self.add(x)
+        """
         for m1, m2 in zip(self.submobjects, self.submobjects[1:]):
-            m2.next_to(m1, direction, **kwargs)
+            m2.next_to(m1, direction, buff, **kwargs)
         if center:
             self.center()
         return self
@@ -1198,8 +1274,21 @@ class Mobject(Container):
 
     def become(self, mobject, copy_submobjects=True):
         """
-        Edit points, colors and submobjects to be idential
+        Edit points, colors and submobjects to be identical
         to another mobject
+
+        Examples
+        --------
+        .. manim:: BecomeScene
+
+            class BecomeScene(Scene):
+                def construct(self):
+                    circ = Circle(fill_color=RED)
+                    square = Square(fill_color=BLUE)
+                    self.add(circ)
+                    self.wait(0.5)
+                    circ.become(square)
+                    self.wait(0.5)
         """
         self.align_data(mobject)
         for sm1, sm2 in zip(self.get_family(), mobject.get_family()):
@@ -1210,9 +1299,10 @@ class Mobject(Container):
     # Errors
     def throw_error_if_no_points(self):
         if self.has_no_points():
-            message = "Cannot call Mobject.{} " + "for a Mobject with no points"
             caller_name = sys._getframe(1).f_code.co_name
-            raise Exception(message.format(caller_name))
+            raise Exception(
+                f"Cannot call Mobject.{caller_name} for a Mobject with no points"
+            )
 
     # About z-index
     def set_z_index(self, z_index_value):
@@ -1250,3 +1340,24 @@ class Group(Mobject):
     def __init__(self, *mobjects, **kwargs):
         Mobject.__init__(self, **kwargs)
         self.add(*mobjects)
+
+
+class _AnimationBuilder:
+    def __init__(self, mobject, generate_target=True):
+        self.mobject = mobject
+        if generate_target:
+            self.mobject.generate_target()
+
+    def __getattr__(self, method_name):
+        method = getattr(self.mobject.target, method_name)
+
+        def update_target(*method_args, **method_kwargs):
+            method(*method_args, **method_kwargs)
+            return _AnimationBuilder(self.mobject, generate_target=False)
+
+        return update_target
+
+    def build(self):
+        from ..animation.transform import _MethodAnimation
+
+        return _MethodAnimation(self.mobject)
