@@ -31,8 +31,7 @@ class DecimalNumber(VMobject):
                 decimal.add_updater(lambda d: d.set_value(square.get_center()[1]))
                 self.add(square, decimal)
                 self.play(
-                    square.to_edge,
-                    DOWN,
+                    square.animate.to_edge(DOWN),
                     rate_func=there_and_back,
                     run_time=5,
                 )
@@ -40,21 +39,43 @@ class DecimalNumber(VMobject):
 
     """
 
-    CONFIG = {
-        "num_decimal_places": 2,
-        "include_sign": False,
-        "group_with_commas": True,
-        "digit_to_digit_buff": 0.05,
-        "show_ellipsis": False,
-        "unit": None,  # Aligned to bottom unless it starts with "^"
-        "include_background_rectangle": False,
-        "edge_to_fix": LEFT,
-    }
-
-    def __init__(self, number=0, **kwargs):
+    def __init__(
+        self,
+        number=0,
+        num_decimal_places=2,
+        include_sign=False,
+        group_with_commas=True,
+        digit_to_digit_buff=0.05,
+        show_ellipsis=False,
+        unit=None,  # Aligned to bottom unless it starts with "^"
+        include_background_rectangle=False,
+        edge_to_fix=LEFT,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         self.number = number
-        self.initial_config = kwargs
+        self.num_decimal_places = num_decimal_places
+        self.include_sign = include_sign
+        self.group_with_commas = group_with_commas
+        self.digit_to_digit_buff = digit_to_digit_buff
+        self.show_ellipsis = show_ellipsis
+        self.unit = unit
+        self.include_background_rectangle = include_background_rectangle
+        self.edge_to_fix = edge_to_fix
+
+        self.initial_config = kwargs.copy()
+        self.initial_config.update(
+            {
+                "num_decimal_places": num_decimal_places,
+                "include_sign": include_sign,
+                "group_with_commas": group_with_commas,
+                "digit_to_digit_buff": digit_to_digit_buff,
+                "show_ellipsis": show_ellipsis,
+                "unit": unit,
+                "include_background_rectangle": include_background_rectangle,
+                "edge_to_fix": edge_to_fix,
+            }
+        )
 
         if isinstance(number, complex):
             formatter = self.get_complex_formatter()
@@ -144,7 +165,7 @@ class DecimalNumber(VMobject):
         )
 
     def set_value(self, number, **config):
-        full_config = dict(self.CONFIG)
+        full_config = dict()
         full_config.update(self.initial_config)
         full_config.update(config)
         new_decimal = DecimalNumber(number, **full_config)
@@ -170,9 +191,10 @@ class DecimalNumber(VMobject):
 
 
 class Integer(DecimalNumber):
-    CONFIG = {
-        "num_decimal_places": 0,
-    }
+    def __init__(self, number=0, num_decimal_places=0, **kwargs):
+        DecimalNumber.__init__(
+            self, number=number, num_decimal_places=num_decimal_places, **kwargs
+        )
 
     def get_value(self):
         return int(np.round(super().get_value()))
@@ -187,7 +209,7 @@ class Variable(VMobject):
     ----------
     var : Union[:class:`int`, :class:`float`]
         The python variable you need to keep track of and display.
-    label : Union[:class:`str`, :class:`~.Tex`, :class:`~.MathTex`, :class:`~.Text`, :class:`~.TexSymbol`, :class:`~.SingleStringMathTex`, :class:`~.MathTexFromPresetString`]
+    label : Union[:class:`str`, :class:`~.Tex`, :class:`~.MathTex`, :class:`~.Text`, :class:`~.TexSymbol`, :class:`~.SingleStringMathTex`]
         The label for your variable, for example ``x = ...``. To use math mode, for e.g.
         subscripts, superscripts, etc. simply pass in a raw string.
     var_type : Union[:class:`DecimalNumber`, :class:`Integer`], optional
@@ -200,7 +222,7 @@ class Variable(VMobject):
 
     Attributes
     ----------
-    label : Union[:class:`str`, :class:`~.Tex`, :class:`~.MathTex`, :class:`~.Text`, :class:`~.TexSymbol`, :class:`~.SingleStringMathTex`, :class:`~.MathTexFromPresetString`]
+    label : Union[:class:`str`, :class:`~.Tex`, :class:`~.MathTex`, :class:`~.Text`, :class:`~.TexSymbol`, :class:`~.SingleStringMathTex`]
         The label for your variable, for example ``x = ...``.
     tracker : :class:`~.ValueTracker`
         Useful in updating the value of your variable on-screen.
@@ -238,7 +260,7 @@ class Variable(VMobject):
                 self.wait()
                 var_tracker = on_screen_var.tracker
                 var = 10.5
-                self.play(var_tracker.set_value, var)
+                self.play(var_tracker.animate.set_value(var))
                 self.wait()
 
                 int_var = 0
@@ -252,7 +274,7 @@ class Variable(VMobject):
                 self.wait()
                 var_tracker = on_screen_int_var.tracker
                 var = 10.5
-                self.play(var_tracker.set_value, var)
+                self.play(var_tracker.animate.set_value(var))
                 self.wait()
 
                 # If you wish to have a somewhat more complicated label for your
