@@ -126,34 +126,57 @@ class Code(VGroup):
     """
 
     # tuples in the form (name, aliases, filetypes, mimetypes)
-    # 'language' of CONFIG is aliases or short names
+    # 'language' is aliases or short names
     # For more information about pygments.lexers visit https://pygments.org/docs/lexers/
     # from pygments.lexers import get_all_lexers
     # all_lexers = get_all_lexers()
     styles_list = list(get_all_styles())
     # For more information about pygments.styles visit https://pygments.org/docs/styles/
-    CONFIG = {
-        "tab_width": 3,
-        "line_spacing": 0.3,
-        "scale_factor": 0.5,
-        "font": "Monospac821 BT",
-        "stroke_width": 0,
-        "margin": 0.3,
-        "indentation_chars": "    ",
-        "background": "rectangle",  # or window
-        "background_stroke_width": 1,
-        "background_stroke_color": WHITE,
-        "corner_radius": 0.2,
-        "insert_line_no": True,
-        "line_no_from": 1,
-        "line_no_buff": 0.4,
-        "style": "vim",
-        "language": None,
-        "generate_html_file": False,
-    }
 
-    def __init__(self, file_name=None, **kwargs):
-        VGroup.__init__(self, **kwargs)
+    def __init__(
+        self,
+        file_name=None,
+        tab_width=3,
+        line_spacing=0.3,
+        scale_factor=0.5,
+        font="Monospac821 BT",
+        stroke_width=0,
+        margin=0.3,
+        indentation_chars="    ",
+        background="rectangle",  # or window
+        background_stroke_width=1,
+        background_stroke_color=WHITE,
+        corner_radius=0.2,
+        insert_line_no=True,
+        line_no_from=1,
+        line_no_buff=0.4,
+        style="vim",
+        language=None,
+        generate_html_file=False,
+        **kwargs,
+    ):
+        VGroup.__init__(
+            self,
+            stroke_width=stroke_width,
+            background_stroke_color=background_stroke_color,
+            background_stroke_width=background_stroke_width,
+            **kwargs,
+        )
+        self.tab_width = tab_width
+        self.line_spacing = line_spacing
+        self.scale_factor = scale_factor
+        self.font = font
+        self.margin = margin
+        self.indentation_chars = indentation_chars
+        self.background = background
+        self.corner_radius = corner_radius
+        self.insert_line_no = insert_line_no
+        self.line_no_from = line_no_from
+        self.line_no_buff = line_no_buff
+        self.style = style
+        self.language = language
+        self.generate_html_file = generate_html_file
+
         self.file_name = file_name or self.file_name
         self.ensure_valid_file()
         self.style = self.style.lower()
@@ -168,11 +191,11 @@ class Code(VGroup):
             self.line_numbers.next_to(self.code, direction=LEFT, buff=self.line_no_buff)
         if self.background == "rectangle":
             if self.insert_line_no:
-                forground = VGroup(self.code, self.line_numbers)
+                foreground = VGroup(self.code, self.line_numbers)
             else:
-                forground = self.code
+                foreground = self.code
             rect = SurroundingRectangle(
-                forground,
+                foreground,
                 buff=self.margin,
                 color=self.background_color,
                 fill_color=self.background_color,
@@ -184,11 +207,11 @@ class Code(VGroup):
             self.background_mobject = VGroup(rect)
         else:
             if self.insert_line_no:
-                forground = VGroup(self.code, self.line_numbers)
+                foreground = VGroup(self.code, self.line_numbers)
             else:
-                forground = self.code
-            height = forground.get_height() + 0.1 * 3 + 2 * self.margin
-            width = forground.get_width() + 0.1 * 3 + 2 * self.margin
+                foreground = self.code
+            height = foreground.get_height() + 0.1 * 3 + 2 * self.margin
+            width = foreground.get_width() + 0.1 * 3 + 2 * self.margin
 
             rect = RoundedRectangle(
                 corner_radius=self.corner_radius,
@@ -211,8 +234,8 @@ class Code(VGroup):
             )
 
             self.background_mobject = VGroup(rect, buttons)
-            x = (height - forground.get_height()) / 2 - 0.1 * 3
-            self.background_mobject.shift(forground.get_center())
+            x = (height - foreground.get_height()) / 2 - 0.1 * 3
+            self.background_mobject.shift(foreground.get_center())
             self.background_mobject.shift(UP * x)
         if self.insert_line_no:
             VGroup.__init__(
@@ -224,7 +247,7 @@ class Code(VGroup):
                 self.background_mobject,
                 Dot(fill_opacity=0, stroke_opacity=0),
                 self.code,
-                **kwargs
+                **kwargs,
             )
         self.move_to(np.array([0, 0, 0]))
 
@@ -240,8 +263,9 @@ class Code(VGroup):
             if os.path.exists(path):
                 self.file_path = path
                 return
-        error = "From: {}, could not find {} at either of these locations: {}".format(
-            os.getcwd(), self.file_name, possible_paths
+        error = (
+            f"From: {os.getcwd()}, could not find {self.file_name} at either "
+            + "of these locations: {possible_paths}"
         )
         raise IOError(error)
 
@@ -262,7 +286,8 @@ class Code(VGroup):
             line_spacing=self.line_spacing,
             alignment="right",
             font=self.font,
-            stroke_width=self.stroke_width
+            disable_ligatures=True,
+            stroke_width=self.stroke_width,
         ).scale(self.scale_factor)
         for i in line_numbers:
             i.set_color(self.default_color)
@@ -287,7 +312,8 @@ class Code(VGroup):
             line_spacing=self.line_spacing,
             tab_width=self.tab_width,
             font=self.font,
-            stroke_width=self.stroke_width
+            disable_ligatures=True,
+            stroke_width=self.stroke_width,
         ).scale(self.scale_factor)
         for line_no in range(code.__len__()):
             line = code.chars[line_no]
