@@ -42,37 +42,59 @@ from ...utils.space_ops import shoelace_direction
 
 
 class VMobject(Mobject):
-    CONFIG = {
-        "fill_color": None,
-        "fill_opacity": 0.0,
-        "stroke_color": None,
-        "stroke_opacity": 1.0,
-        "stroke_width": DEFAULT_STROKE_WIDTH,
+    def __init__(
+        self,
+        fill_color=None,
+        fill_opacity=0.0,
+        stroke_color=None,
+        stroke_opacity=1.0,
+        stroke_width=DEFAULT_STROKE_WIDTH,
         # The purpose of background stroke is to have
         # something that won't overlap the fill, e.g.
         # For text against some textured background
-        "background_stroke_color": BLACK,
-        "background_stroke_opacity": 1.0,
-        "background_stroke_width": 0,
+        background_stroke_color=BLACK,
+        background_stroke_opacity=1.0,
+        background_stroke_width=0,
         # When a color c is set, there will be a second color
         # computed based on interpolating c to WHITE by with
         # sheen_factor, and the display will gradient to this
         # secondary color in the direction of sheen_direction.
-        "sheen_factor": 0.0,
-        "sheen_direction": UL,
+        sheen_factor=0.0,
+        sheen_direction=UL,
         # Indicates that it will not be displayed, but
         # that it should count in parent mobject's path
-        "close_new_points": False,
-        "pre_function_handle_to_anchor_scale_factor": 0.01,
-        "make_smooth_after_applying_functions": False,
-        "background_image_file": None,
-        "shade_in_3d": False,
+        close_new_points=False,
+        pre_function_handle_to_anchor_scale_factor=0.01,
+        make_smooth_after_applying_functions=False,
+        background_image_file=None,
+        shade_in_3d=False,
         # This is within a pixel
         # TODO, do we care about accounting for
         # varying zoom levels?
-        "tolerance_for_point_equality": 1e-6,
-        "n_points_per_cubic_curve": 4,
-    }
+        tolerance_for_point_equality=1e-6,
+        n_points_per_cubic_curve=4,
+        **kwargs,
+    ):
+        self.fill_color = fill_color
+        self.fill_opacity = fill_opacity
+        self.stroke_color = stroke_color
+        self.stroke_opacity = stroke_opacity
+        self.stroke_width = stroke_width
+        self.background_stroke_color = background_stroke_color
+        self.background_stroke_opacity = background_stroke_opacity
+        self.background_stroke_width = background_stroke_width
+        self.sheen_factor = sheen_factor
+        self.sheen_direction = sheen_direction
+        self.close_new_points = close_new_points
+        self.pre_function_handle_to_anchor_scale_factor = (
+            pre_function_handle_to_anchor_scale_factor
+        )
+        self.make_smooth_after_applying_functions = make_smooth_after_applying_functions
+        self.background_image_file = background_image_file
+        self.shade_in_3d = shade_in_3d
+        self.tolerance_for_point_equality = tolerance_for_point_equality
+        self.n_points_per_cubic_curve = n_points_per_cubic_curve
+        Mobject.__init__(self, **kwargs)
 
     def get_group_class(self):
         return VGroup
@@ -463,7 +485,7 @@ class VMobject(Mobject):
 
     def add_smooth_curve_to(self, *points):
         """
-        If two points are passed in, the first is intepretted
+        If two points are passed in, the first is interpreted
         as a handle, the second as an anchor
         """
         if len(points) == 1:
@@ -473,7 +495,7 @@ class VMobject(Mobject):
             handle2, new_anchor = points
         else:
             name = sys._getframe(0).f_code.co_name
-            raise ValueError("Only call {} with 1 or 2 points".format(name))
+            raise ValueError(f"Only call {name} with 1 or 2 points")
 
         if self.has_new_path_started():
             self.add_line_to(new_anchor)
@@ -617,7 +639,7 @@ class VMobject(Mobject):
 
         Generator to not materialize a list or np.array needlessly.
         """
-        nppcc = VMobject.CONFIG["n_points_per_cubic_curve"]
+        nppcc = self.n_points_per_cubic_curve
         remainder = len(points) % nppcc
         points = points[: len(points) - remainder]
         return (points[i : i + nppcc] for i in range(0, len(points), nppcc))
@@ -722,7 +744,7 @@ class VMobject(Mobject):
 
         for mob in self, vmobject:
             # If there are no points, add one to
-            # whereever the "center" is
+            # wherever the "center" is
             if mob.has_no_points():
                 mob.start_new_path(mob.get_center())
             # If there's only one point, turn it into
@@ -953,6 +975,31 @@ class VGroup(VMobject):
     Examples
     --------
 
+    To add :class:`~.VMobject`s to a :class:`~.VGroup`, you can either use the
+    :meth:`~.VGroup.add` method, or use the `+` and `+=` operators. Similarly, you
+    can subtract elements of a VGroup via :meth:`~.VGroup.remove` method, or
+    `-` and `-=` operators:
+
+        >>> from manim import Triangle, Square, VGroup
+        >>> vg = VGroup()
+        >>> triangle, square = Triangle(), Square()
+        >>> vg.add(triangle)
+        VGroup(Triangle)
+        >>> vg + square   # a new VGroup is constructed
+        VGroup(Triangle, Square)
+        >>> vg            # not modified
+        VGroup(Triangle)
+        >>> vg += square; vg  # modifies vg
+        VGroup(Triangle, Square)
+        >>> vg.remove(triangle)
+        VGroup(Square)
+        >>> vg - square; # a new VGroup is constructed
+        VGroup()
+        >>> vg   # not modified
+        VGroup(Square)
+        >>> vg -= square; vg # modifies vg
+        VGroup()
+
     .. manim:: ArcShapeIris
         :save_last_frame:
 
@@ -992,16 +1039,61 @@ class VGroup(VMobject):
 
         Returns
         -------
-        None
+        :class:`VGroup`
 
         Raises
         ------
         TypeError
             If one element of the list is not an instance of VMobject
+
+        Examples
+        --------
+        .. manim:: AddToVGroup
+
+            class AddToVGroup(Scene):
+                def construct(self):
+                    circle_red = Circle(color=RED)
+                    circle_green = Circle(color=GREEN)
+                    circle_blue = Circle(color=BLUE)
+                    circle_red.shift(LEFT)
+                    circle_blue.shift(RIGHT)
+                    gr = VGroup(circle_red, circle_green)
+                    gr2 = VGroup(circle_blue) # Constructor uses add directly
+                    self.add(gr,gr2)
+                    self.wait()
+                    gr += gr2 # Add group to another
+                    self.play(
+                        gr.animate.shift(DOWN),
+                    )
+                    gr -= gr2 # Remove group
+                    self.play( # Animate groups separately
+                        gr.animate.shift(LEFT),
+                        gr2.animate.shift(UP),
+                    )
+                    self.play( #Animate groups without modification
+                        (gr+gr2).animate.shift(RIGHT)
+                    )
+                    self.play( # Animate group without component
+                        (gr-circle_red).animate.shift(RIGHT)
+                    )
         """
         if not all(isinstance(m, VMobject) for m in vmobjects):
             raise TypeError("All submobjects must be of type VMobject")
-        super().add(*vmobjects)
+        return super().add(*vmobjects)
+
+    def __add__(self, vmobject):
+        return VGroup(*self.submobjects, vmobject)
+
+    def __iadd__(self, vmobject):
+        return self.add(vmobject)
+
+    def __sub__(self, vmobject):
+        copy = VGroup(*self.submobjects)
+        copy.remove(vmobject)
+        return copy
+
+    def __isub__(self, vmobject):
+        return self.remove(vmobject)
 
 
 class VDict(VMobject):
@@ -1018,7 +1110,7 @@ class VDict(VMobject):
             especially when there are a lot of mobjects in the
             :class:`VDict`. Defaults to False.
     kwargs : Any
-            Other arguments to be passed to `Mobject` or the CONFIG.
+            Other arguments to be passed to `Mobject`.
 
     Attributes
     ----------
@@ -1064,14 +1156,14 @@ class VDict(VMobject):
 
                 # access submobjects like a python dict
                 my_dict["t"].set_color(PURPLE)
-                self.play(my_dict["t"].scale, 3)
+                self.play(my_dict["t"].animate.scale(3))
                 self.wait()
 
                 # also supports python dict styled reassignment
                 my_dict["t"] = Tex("Some other text").set_color(BLUE)
                 self.wait()
 
-                # remove submoject by key
+                # remove submobject by key
                 my_dict.remove("t")
                 self.wait()
 
@@ -1331,16 +1423,25 @@ class VDict(VMobject):
 
 
 class VectorizedPoint(VMobject):
-    CONFIG = {
-        "color": BLACK,
-        "fill_opacity": 0,
-        "stroke_width": 0,
-        "artificial_width": 0.01,
-        "artificial_height": 0.01,
-    }
-
-    def __init__(self, location=ORIGIN, **kwargs):
-        VMobject.__init__(self, **kwargs)
+    def __init__(
+        self,
+        location=ORIGIN,
+        color=BLACK,
+        fill_opacity=0,
+        stroke_width=0,
+        artificial_width=0.01,
+        artificial_height=0.01,
+        **kwargs,
+    ):
+        self.artificial_width = artificial_width
+        self.artificial_height = artificial_height
+        VMobject.__init__(
+            self,
+            color=color,
+            fill_opacity=fill_opacity,
+            stroke_width=stroke_width,
+            **kwargs,
+        )
         self.set_points(np.array([location]))
 
     def get_width(self):
@@ -1357,6 +1458,22 @@ class VectorizedPoint(VMobject):
 
 
 class CurvesAsSubmobjects(VGroup):
+    """Convert a curve's elements to submobjects.
+
+    Examples
+    --------
+    .. manim:: LineGradientExample
+        :save_last_frame:
+
+        class LineGradientExample(Scene):
+            def construct(self):
+                curve = ParametricFunction(lambda t: [t, np.sin(t), 0], t_min = -PI, t_max=PI,stroke_width=10)
+                new_curve = CurvesAsSubmobjects(curve)
+                new_curve.set_color_by_gradient(BLUE, RED)
+                self.add(new_curve.shift(UP), curve)
+
+    """
+
     def __init__(self, vmobject, **kwargs):
         VGroup.__init__(self, **kwargs)
         tuples = vmobject.get_cubic_bezier_tuples()
@@ -1368,11 +1485,12 @@ class CurvesAsSubmobjects(VGroup):
 
 
 class DashedVMobject(VMobject):
-    CONFIG = {"num_dashes": 15, "positive_space_ratio": 0.5, "color": WHITE}
-
-    def __init__(self, vmobject, **kwargs):
-        VMobject.__init__(self, **kwargs)
-        num_dashes = self.num_dashes
+    def __init__(
+        self, vmobject, num_dashes=15, positive_space_ratio=0.5, color=WHITE, **kwargs
+    ):
+        self.num_dashes = num_dashes
+        self.positive_space_ratio = positive_space_ratio
+        VMobject.__init__(self, color=color, **kwargs)
         ps_ratio = self.positive_space_ratio
         if num_dashes > 0:
             # End points of the unit interval for division
@@ -1382,9 +1500,16 @@ class DashedVMobject(VMobject):
             full_d_alpha = 1.0 / num_dashes
             partial_d_alpha = full_d_alpha * ps_ratio
 
+            # Shifts the alphas and removes the last dash
+            # to give closed shapes even spacing
+            if vmobject.is_closed():
+                alphas += partial_d_alpha / 2
+                np.delete(alphas, -1)
+
             # Rescale so that the last point of vmobject will
             # be the end of the last dash
-            alphas /= 1 - full_d_alpha + partial_d_alpha
+            else:
+                alphas /= 1 - full_d_alpha + partial_d_alpha
 
             self.add(
                 *[
