@@ -20,7 +20,7 @@ def handle_caching_play(func):
     def wrapper(self, scene, *args, **kwargs):
         self.skip_animations = self.original_skipping_status
         self.update_skipping_status()
-        animations = scene.compile_play_args_to_animation_list(*args, **kwargs)
+        animations = scene.compile_animations(*args, **kwargs)
         scene.add_mobjects_from_animations(animations)
         if self.skip_animations:
             logger.debug(f"Skipping animation {self.num_plays}")
@@ -42,7 +42,7 @@ def handle_caching_play(func):
                 )
                 self.skip_animations = True
         else:
-            hash_play = "uncached_{:05}".format(self.num_plays)
+            hash_play = f"uncached_{self.num_plays:05}"
         self.animations_hashes.append(hash_play)
         self.file_writer.add_partial_movie_file(hash_play)
         logger.debug(
